<?php

/**
 * @file
 * Page callbacks for Geo Redirect module.
 */

/**
 * Geo redirect listing page.
 */
function geo_redirect_listing() {
  $output = '';

  $result = db_query("SELECT gid, country_code, redirect_url FROM {geo_redirect_list}");

  $countries = _geo_redirect_get_country_names();

  $rows = array();
  $header = array('Country', 'Redirect URL', 'Operations');
  while ($item = db_fetch_object($result)) {
    $row = array();
    $row[] = $countries[$item->country_code];
    $row[] = l($item->redirect_url, $item->redirect_url);
    $row[] = l(t('Edit'), 'admin/settings/geo-redirect/edit/' . $item->gid) . ' | ' . l(t('Delete'), 'admin/settings/geo-redirect/delete/' . $item->gid);
    $rows[] = $row;
  }
  if (!empty($rows)) {
    $output .= '<p>' . l(t('Add new redirection'), 'admin/settings/geo-redirect/add') . '</p>';
    $output .= theme('table', $header, $rows);
  }
  else {
    $output .= '<p>' . t('No redirections available.') . ' ';
    $output .= l(t('Add now.'), 'admin/settings/geo-redirect/add') . '</p>';
  }
  return $output;
}

/**
 * Add redirection form.
 */
function geo_redirect_add(&$form_state) {
  $countries = variable_get('geo_redirect_countries', array());
  $array_sort = asort($countries);
  $form['geo_redirect_country'] = array(
    '#type' => 'select',
    '#title' => t('Select country'),
    '#options' => $countries,
    '#description' => t('Select the country for which you want the site to be redirected.'),
    '#required' => TRUE,
  );
  $form['geo_redirect_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Enter URL'),
    '#required' => TRUE,
    '#description' => t('Enter the URL where you want to redirect the user from above country e.g. (@example).', array('@example' => 'http://www.example.com')),
    '#required' => TRUE,
  );
  $form['geo_redirect_user_allowed'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow <em>@user</em> path.', array('@user' => '/user')),
    '#description' => t('If you check this box, user from above country can access the path <em>/user</em>.</p> <p><strong>It is strongly recommanded that you should check this box, if you are trying to redirect users from your country.</strong>'),
    '#default_value' => 1,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Add'),
  );
  $form['#validate'][] = 'geo_redirect_add_validate';
  $form['#redirect'] = 'admin/settings/geo-redirect';
  return $form;
}

/**
 * Validations for add redirection form.
 */
function geo_redirect_add_validate($form, &$form_state) {
  // Check if entered url is valid.
  if (!valid_url($form_state['values']['geo_redirect_url'], TRUE)) {
    form_set_error('geo_redirect_url', t('Please enter valid URL.'));
  }
}

/**
 * Submit handler for add redirection form.
 */
function geo_redirect_add_submit($form, &$form_state) {

  // Add entry into database.
  $record = new stdClass();
  $record->country_code = $form_state['values']['geo_redirect_country'];
  $record->redirect_url = $form_state['values']['geo_redirect_url'];
  $record->is_user_allowed = $form_state['values']['geo_redirect_user_allowed'];
  drupal_write_record('geo_redirect_list', $record);

  // We are removing selected country from option
  // to avoid extra validations if same country is added again.
  $countries = variable_get('geo_redirect_countries', array());
  unset($countries[$form_state['values']['geo_redirect_country']]);
  variable_set('geo_redirect_countries', $countries);

  drupal_set_message(t('Added to redirect list successfully.'), 'status');
}

/**
 * Edit redirection form.
 */
function geo_redirect_edit(&$form_state, $gid) {
  // Get the record from database.
  $result = db_query("SELECT gid, country_code, redirect_url, is_user_allowed FROM {geo_redirect_list} WHERE gid = %d", $gid);
  $item = db_fetch_object($result);

  $countries = _geo_redirect_get_country_names();

  // Add current country in options since we have removed it while adding.
  $redirect_country_names = variable_get('geo_redirect_countries', array());
  $redirect_country_names[$item->country_code] = $countries[$item->country_code];
  $array_sort = asort($redirect_country_names);

  // Store these values to use in submit handler.
  $form_state['storage']['value'] = $gid;
  $form_state['storage']['country_array'] = $redirect_country_names;

  $form['geo_redirect_edit_country'] = array(
    '#type' => 'select',
    '#title' => t('Select country'),
    '#options' => $redirect_country_names,
    '#description' => t('Select the country for which you want the site to be redirected.'),
    '#required' => TRUE,
    '#default_value' => $item->country_code,
  );
  $form['geo_redirect_edit_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Enter URL'),
    '#required' => TRUE,
    '#description' => t('Enter the URL where you want to redirect the user from above country e.g. (@example).', array('@example' => 'http://www.example.com')),
    '#required' => TRUE,
    '#default_value' => $item->redirect_url,
  );
  $form['geo_redirect_edit_user_allowed'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow <em>@user</em> path.', array('@user' => '/user')),
    '#description' => t('<p>If you check this box, user from above country can access the path <em>/user</em>.</p> <p><strong>It is strongly recommanded that you should check this box, if you are trying to redirect users from your country.</strong></p>'),
    '#default_value' => $item->is_user_allowed,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Update'),
  );
  $form['#validate'][] = 'geo_redirect_edit_validate';
  $form['#redirect'] = 'admin/settings/geo-redirect';
  return $form;
}

/**
 * Validations for edit redirection form.
 */
function geo_redirect_edit_validate($form, &$form_state) {
  if (!valid_url($form_state['values']['geo_redirect_edit_url'], TRUE)) {
    form_set_error('geo_redirect_edit_url', t('Please enter valid URL.'));
  }
}

/**
 * Submit handler for edit redirection form.
 */
function geo_redirect_edit_submit($form, &$form_state) {
  // Get required values from storage.
  $gid = $form_state['storage']['value'];
  $country_names = $form_state['storage']['country_array'];

  // Update the entry in database.
  $record = new stdClass();
  $record->gid = $gid;
  $record->country_code = $form_state['values']['geo_redirect_edit_country'];
  $record->redirect_url = $form_state['values']['geo_redirect_edit_url'];
  $record->is_user_allowed = $form_state['values']['geo_redirect_edit_user_allowed'];
  drupal_write_record('geo_redirect_list', $record, 'gid');

  // Remove selected country from options.
  unset($country_names[$form_state['values']['geo_redirect_edit_country']]);
  variable_set('geo_redirect_countries', $country_names);

  drupal_set_message(t('Redirect list updated successfully.'), 'status');
  drupal_redirect_form($form);
}

/**
 * Delete redirection.
 */
function geo_redirect_delete(&$form_state, $gid) {
  $result = db_query("SELECT gid, country_code, redirect_url, is_user_allowed FROM {geo_redirect_list} WHERE gid = %d", $gid);
  $item = db_fetch_object($result);

  $countries = _geo_redirect_get_country_names();

  $country_code = $item->country_code;
  $current_country = $countries[$country_code];

  // Store required values to use in submit handler.
  $form_state['storage']['value'] = $gid;
  $form_state['storage']['country_names'] = $countries;
  $form_state['storage']['country_code'] = $country_code;

  $form['#redirect'] = 'admin/settings/geo-redirect';

  return confirm_form($form, t('Are you sure you want to delete redirection for <em>%country</em>?', array('%country' => $current_country)), 'admin/settings/geo-redirect');
}

/**
 * Submit handler for deleting redirection.
 */
function geo_redirect_delete_submit($form, &$form_state) {
  // Get required values from storage.
  $gid = $form_state['storage']['value'];
  $countries = $form_state['storage']['country_names'];
  $country_code = $form_state['storage']['country_code'];

  $redirect_country_names = variable_get('geo_redirect_countries', array());
  $redirect_country_names[$country_code] = $countries[$country_code];

  // Delete the record from database.
  db_query("DELETE FROM {geo_redirect_list} WHERE gid = %d", $gid);

  // Add deleted country into options again.
  variable_set('geo_redirect_countries', $redirect_country_names);
  drupal_redirect_form($form);
}
